/*
                       Recycle Bin Object Deleting
 */

#ifndef EDV_RECBIN_DELETE_H
#define EDV_RECBIN_DELETE_H

#include <gtk/gtk.h>

#include "edv_types.h"
#include "edv_recycled_obj.h"


extern const gchar *EDVRecBinDeleteObjectGetError(edv_core_struct *core);

extern gint EDVRecBinDeleteObject(
	edv_core_struct *core,
	const gchar *path,
	GList **index_list_rtn,
	GtkWidget *toplevel,
	const gboolean show_progress, const gboolean interactive,
	gboolean *yes_to_all
);
/* Note that we do not use EDVRecBinDelete() for the above function name
 * because it conflicts with the one that deletes the Recycle Bin window
 */


#endif	/* EDV_RECBIN_DELETE_H */
